-- initialize two rings:
-- R for the variables of the cubic
-- S for the free parameters on a pencil
R = QQ[x_0..x_2]
S = QQ[s_0,s_1]
RS = R**S

-- initialize vectors for the x and s variables
xx = sub(vars(R),RS)
ss = sub(vars(S),RS)

-- the file cubicInvs.m2 contains a hardcoded expression 
-- of the discriminant of plane cubics; we use it to define
-- a handy function that evaluates it.
load "SupportingFiles/cubicInvs.m2"

disc = ff -> (
    apply(compositions(3,3), cc -> (
	    mm = product(3, j-> x_j^(cc_j));
	    ee_cc = diff(mm,ff)));
    Disc())


-- load the rational representatives
load "SupportingFiles/RationalRepresentatives.m2"

-- for every rational representative pp
-- we compute the pencil of cubics Lpp through pp
-- we restrict the discriminant to this pencil
-- we factor this restriction and
-- we characterize the cubics corresponding to the linear factors


-- the non-Bezoutian quatroids with index less than 82, 
-- the MacLane quatroid Q41, and the Fano candidate 63
Nonbez = {6,7,14,23,27,41,63}

Bez = select(toList(1..82), i-> not member(i,Nonbez))

myfile = "result_countReducibleCubics.txt"
myfile << "The proof of Thm. 5.5 relies on the following calculation. 
For the Bezoutian quatroid j, with rational representative p_j, 
we compute the number d_(p_j) of rational cubics through p_j: \n \n"
-- this loop on the Bezoutian quatroids computes the values rp 
-- that is the sum of intersection multiplicities occurring 
-- at reducible cubics




for j in Bez do (
    	if j ==1 then print "Pairs (j,d_(Qj)):";
	Ipp = intersect( apply(8, i-> (
		    minors(2, xx || (transpose ((P_j)_{i})))))); -- define the ideal of 8 points
	Lpp = super (basis(3,Ipp)); -- the degree 3 component, which is spanned by two cubics
    	Lpps  = s_0 * Lpp_(0,0) +s_1*Lpp_(0,1);
    	discpp = disc(Lpps);
	discppFactors = apply(toList factor discpp, f-> (toList f)); -- the factors of the discriminant restricted to the pencil
	rp = 0; -- initialize the intersection multiplicity at reducible elements
    	apply(discppFactors, fm -> (
		f = fm_0; -- the factor of the discriminant
		m = fm_1; -- its multiplicity
		-- if the factor is linear, we check whether the corresponding cubic on the pencil 
		-- is reducible and we account for its multiplicity
                if degree(f) == {0,1} then (
		    cubId =(ideal( Lpps % f)) : (ideal (s_0*s_1));
    	    	    Pcub = primaryDecomposition(cubId);
		    if #Pcub > 1 then rp = rp + m)));
	print (j, 12 - rp);
    	myfile << "d_(p_"|toString(j)|") = ";
	myfile << toString(12-rp);
	myfile << "\n" ) 



-- this loop identifies each reducible cubic.
-- all reducible cubics are either conic+secant or triangle:
-- this is verified by checking that the singular locus is reduced of codimension 2.
-- knowing this we simply check if the cubic has two or three irreducible factors.


myfile << "\n \n Moreover, we record which reducible cubics occur through each representative.
conicsecant indicates a conic+secant, with expected multiplicity 2;
triangle indicates a triangle, with expected multiplicity 3;
the suffix Blue indicates that the corresponding cubic appears with multiplicity one more than expected. \n \n"
flagRed = 0
flagLin = 0
-- this flag turns '1' if one of the reducible cubics is different 
-- from a conic+secant or a triangle
for j in Bez do (
	if j == 1 then print "Each Bezoutian quatroid with the corresponding reducible cubics:";
	Ipp = intersect( apply(8, i-> (
		    minors(2, xx || (transpose ((P_j)_{i}))))));
	Lpp = super (basis(3,Ipp));
    	Lpps  = s_0 * Lpp_(0,0) +s_1*Lpp_(0,1);
    	discpp = disc(Lpps);
	discppFactors = apply(toList factor discpp, f-> (toList f)); -- the factors of the discriminant restricted to the pencil
    	Reds = sort delete(null,apply(discppFactors, fm -> (
		f = fm_0;
		m = fm_1;
		if ( (degree(f))_1 > 1 and m > 1) then ( 
			flagLin = 1); -- this flag turns to 1 if one higher degree factor appears with multiplicity
                if (degree(f))_1 == 1 then (
		    cubId =(ideal( Lpps % f)) : (ideal (s_0*s_1));
    	    	    Pcub = primaryDecomposition(cubId);
		    Scub = ideal singularLocus(cubId); -- the singular locus of the reducible cubic
    	    	    if ((codim Scub != 2) or (degree(Scub) != degree(radical Scub))) then ( 
		    	flagRed = 1);
		    if #Pcub == 1 then ( if m > 1 then (
			    flagLin = 1));
		    if #Pcub == 2 then type = "conicsecant"; -- if the cubic has two factors it is conic+secant
		    if #Pcub == 3 then type = "triangle"; -- if the cubic has three factors it is a triangle
		    if #Pcub < m then (type = type|"Blue"); -- if the multiplicity is higher than expected, we add a Blue mark.
    	    	    type))));
    	myfile << "p_"|toString(j)|" has the following reducible cubics \n";
	myfile << toString(Reds) | "\n";
	print (j , Reds));
flagLin
flagRed
myfile << "\n \n The flag flagRed is 0 if all occurring reducible cubics are either conic+secant or triangle and 1 otherwise. \n"
myfile << "After the computation, flagRed is "|toString(flagRed)|"\n \n" 
myfile << "\n \n The flag flagLin is 0 if all occurring irreducible cubics are appear with multiplicity 1 on the pencil. \n"
myfile << "After the computation, flagLin is "|toString(flagLin)|"\n \n" << close

