-- load all quatroids. The list of all quatroids can be outputed with QQQ
load "SupportingFiles/AllQuatroids.m2"

-- for instance
QQQ_21


-- load all rational representatives. P_j is the rational represenative of quatroid Q_j
-- P_41 and P_63 are not defined

load "SupportingFiles/RationalRepresentatives.m2"

-- for instance
P_21

----
-- veronese: takes a 3xm matrix and makes it into a 6xm matrix whose columns are 
-- the 2-veronese embedding of the columns of the original matrix
veronese = M->(
    m = numcols(M);
    VM = matrix for i from 0 to m-1 list {M_(0,i)^2,M_(1,i)^2,M_(2,i)^2,M_(0,i)*M_(1,i),M_(0,i)*M_(2,i),M_(1,i)*M_(2,i)};
    return(VM))


-- lineCondition returns the polynomial enforcing a specific line condition on the columns of X 
lineCondition = (X,I)->(
    Xx = submatrix(X,{0,1,2},for i in I list i-1);
    return(det(Xx));
    )

-- conicCondition returns the polynomial a specific conic condition on the columns of X 
conicCondition = (X,J)->(
    Xx = submatrix(X,{0,1,2}, for i in J list i-1);
    return(det(veronese(Xx)));
    )
    
-- Quatroid returns the quatroid represented by a given set of points
Quatroid = X -> (
    IX = delete(null,apply(subsets(numcols(X),3), ss -> (
		lC = lineCondition(X,ss+{1,1,1});
		if lC == 0_(ring lC) then ss +{1,1,1})));
    IY = delete(null,apply(subsets(numcols(X),6), ss -> (
		cC = conicCondition(X,ss+{1,1,1,1,1,1});
		if cC == 0_(ring cC) then ss +{1,1,1,1,1,1})));
    rIY = delete(null,apply(IY, jjj -> (
	    irr = true;
	    apply(IX, iii-> (
		    if isSubset(iii,jjj) then irr = false));
	    if irr then jjj)));
    return(IX|rIY))
		    

----


-- Quatroid(P_j) and QQQ_j are the same for all quatroids;
-- this shows that indeed P_j is a representative of Q_j

-- for instance
Quatroid(P_21)
QQQ_21


myfile = "result_testingRepresentatives.txt"
-- we run it on all quatroids except Q_41 and Q_63
for q from 1 to 40 do (
    	QP = Quatroid(P_q);
	string = "The configuration P_"|toString(q)|" is a representative of Quatroid Q_"|toString(q)|": \n";
	myfile << string;
	myfile << toString((sort (QP)== sort(QQQ_q)))|" \n");
for q from 42 to 62 do (
	QP = Quatroid(P_q);
	string = "The configuration P_"|toString(q)|" is a representative of Quatroid Q_"|toString(q)|": \n";
	myfile << string;
	myfile << toString((sort (QP)== sort(QQQ_q)))|" \n");
for q from 64 to 126 do (
	QP = Quatroid(P_q);
	string = "The configuration P_"|toString(q)|" is a representative of Quatroid Q_"|toString(q)|": \n";
	myfile << string;
	myfile << toString((sort (QP)== sort(QQQ_q)))|" \n");
myfile << close

